import { Component } from '@angular/core';
import { IonicModule,AlertController } from '@ionic/angular';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { addIcons } from 'ionicons';
import {
  chevronBack,
  settings,
  cloudUpload,
  chevronForward,
  statsChart,
  diamond,
  calendar,
  alarm,
  star,
  videocam,
  trophy,
  nutrition,
  wallet,
  gift,
  add,
  barbell,
  restaurant,
  shareSocial,
  person
} from 'ionicons/icons';
import { CloudUser } from 'src/lib/ncloud';

@Component({
  selector: 'app-tab4',
  templateUrl: 'tab4.page.html',
  styleUrls: ['tab4.page.scss'],
  standalone: true,
  imports: [IonicModule, CommonModule, FormsModule]
})
export class Tab4Page {
  vipPanelOpen = false;
  currentUser: CloudUser | null = null;
  isLoggedIn = false;
  username = '请登录';

  constructor(private alertCtrl: AlertController) {
    addIcons({
      settings, cloudUpload, chevronForward, statsChart,
      diamond, calendar, alarm, star, videocam, trophy,
      nutrition, wallet, gift, person
    });
    this.checkLoginStatus();
  }

  async checkLoginStatus() {
    this.currentUser = new CloudUser();
    const user = await this.currentUser.current();
    if (user && user.id) {
      this.isLoggedIn = true;
      this.username = user.get('username') || '用户';
    } else {
      this.isLoggedIn = false;
      this.username = '请登录';
    }
  }

  async showLoginAlert() {
    if (this.isLoggedIn) return;

    const alert = await this.alertCtrl.create({
      header: '登录',
      inputs: [
        {
          name: 'username',
          type: 'text',
          placeholder: '用户名'
        },
        {
          name: 'password',
          type: 'password',
          placeholder: '密码'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '登录',
          handler: async (data:any) => {
            if (!data.username || !data.password) {
              return false; // 阻止关闭
            }
            await this.handleLogin(data.username, data.password);
            return true;
          }
        },
        {
          text: '注册',
          handler: async (data:any) => {
            if (!data.username || !data.password) {
              return false; // 阻止关闭
            }
            await this.handleSignUp(data.username, data.password);
            return true;
          }
        }
      ]
    });

    await alert.present();
  }

  async handleLogin(username: string, password: string) {
    const user = new CloudUser();
    try {
      await user.login(username, password);
      if (user.id) {
        this.isLoggedIn = true;
        this.username = username;
      } else {
        this.showErrorAlert('登录失败');
      }
    } catch (error) {
      this.showErrorAlert('登录错误: ' + (error instanceof Error ? error.message : '未知错误'));
    }
  }

  async handleSignUp(username: string, password: string) {
    const user = new CloudUser();
    try {
      await user.signUp(username, password);
      if (user.id) {
        this.isLoggedIn = true;
        this.username = username;
      } else {
        this.showErrorAlert('注册失败');
      }
    } catch (error) {
      this.showErrorAlert('注册错误: ' + (error instanceof Error ? error.message : '未知错误'));
    }
  }

  async showErrorAlert(message: string) {
    const alert = await this.alertCtrl.create({
      header: '错误',
      message: message,
      buttons: ['确定']
    });
    await alert.present();
  }

  async logout() {
    if (!this.isLoggedIn) return;

    const user = new CloudUser();
    await user.logout();
    this.isLoggedIn = false;
    this.username = '请登录';
  }


  // 顶部栏操作
  goBack() {
    console.log('返回上一页');
  }

  goToSettings() {
    console.log('跳转到设置页面');
  }

  // 运动数据卡片
  goToDataDetails() {
    console.log('跳转到数据详情');
  }

  // 会员服务
  toggleVipPanel() {
    this.vipPanelOpen = !this.vipPanelOpen;
  }

  // 功能网格操作
  goToFavorites() {
    console.log('跳转到收藏与加油');
  }

  goToCourses() {
    console.log('跳转到我的课程');
  }

  goToActivities() {
    console.log('跳转到我的活动');
  }

  showLockedFeature() {
    console.log('显示功能锁定提示');
  }

  goToOrders() {
    console.log('跳转到订单与钱包');
  }

  goToRewards() {
    console.log('跳转到领福利');
  }

  // 发布操作
  createSportRecord() {
    console.log('创建运动打卡');
  }

  createDietRecord() {
    console.log('创建饮食记录');
  }

  shareMoment() {
    console.log('分享动态');
  }
}
